@@ -292,7 +292,7 @@ def main_standalone( argc, argv ):
         ext_Info() << "Time = " << runTime.timeName() << nl << nl
         
         from Foam.finiteVolume.cfdTools.general.include import readSIMPLEControls
-        simple, nNonOrthCorr, momentumPredictor, fluxGradp, transonic = readSIMPLEControls( mesh )
+        simple, nNonOrthCorr, momentumPredictor, transonic = readSIMPLEControls( mesh )
         
         eqnResidual, maxResidual, convergenceCriterion = initConvergenceCheck( simple )
         
@@ -327,8 +327,8 @@ def main_standalone( argc, argv ):
 
 #--------------------------------------------------------------------------------------
 import sys, os
-from Foam import FOAM_BRANCH_VERSION
-if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
+from Foam import FOAM_REF_VERSION
+if FOAM_REF_VERSION( ">=", "010700" ):
    if __name__ == "__main__" :
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
@@ -336,7 +336,7 @@ if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
    pass
 else:
    from Foam.OpenFOAM import ext_Info
-   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.6-ext or higher \n "
+   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.7.0 or higher \n "
 
 
 #--------------------------------------------------------------------------------------
